@@ -2,14 +2,14 @@ package ACME::FunkyDocs;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 BEGIN {
     if (1) {
-        require ACME::FunyDocs::Modern;
+        require ACME::FunkyDocs::Modern;
     }
     else {
-        require ACME::FunyDocs::Legacy;
+        require ACME::FunkyDocs::Legacy;
     }
 }
 
