@@ -1,18 +1,18 @@
-package ACME::FunyDocs::Modern;
+package ACME::FunkyDocs::Modern;
 use strict;
 use warnings;
 
 sub import {
     my $class = shift;
     if ($class eq __PACKAGE__) {
-        unshift @_, 'ACME::FunyDocs';
-        goto &ACME::FunyDocs::import;
+        unshift @_, 'ACME::FunkyDocs';
+        goto &ACME::FunkyDocs::import;
     }
 
     die "This should not happen...";
 }
 
-package ACME::FunyDocs;
+package ACME::FunkyDocs;
 use strict;
 use warnings;
 
